# ModelJoinedModelOutputDetailsResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**model_id** | **str** |  | 
**latest_train_job_updated_at** | **datetime** |  | 
**model_job_output_id** | **str** |  | 
**model_job_id** | **str** |  | 
**att_value** | **str** |  | 
**att_direction** | **str** |  | 
**att_se** | **str** |  | 
**ate_value** | **str** |  | 
**ate_direction** | **str** |  | 
**ate_se** | **str** |  | 
**top_impact_quartile_ate_value** | **str** |  | 
**top_impact_quartile_ate_direction** | **str** |  | 
**top_impact_quartile_se** | **str** |  | 
**treated_records** | **float** |  | 
**total_records** | **float** |  | 
**n_features** | **float** |  | 
**average_outcome_all** | **str** |  | 
**average_outcome_treated** | **str** |  | 
**average_outcome_untreated** | **str** |  | 
**spearman_stability** | **str** |  | 
**target_method** | **str** |  | 
**r2** | **str** |  | 
**auc** | **str** |  | 
**n_records** | **float** |  | 
**risk_average_outcome** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

